==> ultra-erp-clean-v2.1.zip: src/Views/sales/orders/index.php <==
<h5>Sotuv — Buyurtmalar</h5>
<button class="btn btn-primary btn-sm mb-2" data-bs-toggle="modal" data-bs-target="#oNew"><i class="bi bi-bag-check"></i> Yangi buyurtma</button>
<table class="table table-sm table-hover">
<thead><tr><th>Kod</th><th>Sana</th><th>Mijoz</th><th class="text-end">Jami</th><th>Holat</th><th></th></tr></thead>
<tbody><?php foreach($rows as $r): ?><tr><td><?=$r['code']?></td><td><?=$r['date']?></td><td><?=$r['customer_id']?></td><td class="text-end"><?=$r['total']?></td><td><?=$r['status']?></td>
<td class="text-end"><form method="post" action="?r=sales/orders/delete" onsubmit="return confirm('O‘chirish?')" class="d-inline"><input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button></form></td></tr><?php endforeach; ?></tbody>
</table>

<div class="modal fade" id="oNew" tabindex="-1"><div class="modal-dialog modal-xl"><div class="modal-content">
<div class="modal-header py-2"><h6 class="modal-title">Yangi buyurtma</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="?r=sales/orders/create"><div class="modal-body">
  <div class="row row-cols-1 row-cols-md-3 g-2">
    <div class="col"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
    <div class="col"><label class="form-label">Sana</label><input type="date" class="form-control form-control-sm" name="date" required></div>
    <div class="col"><label class="form-label">Mijoz ID</label><input class="form-control form-control-sm" name="customer_id"></div>
  </div><hr class="my-2">
  <table class="table table-sm" id="oItems"><thead><tr><th>Mahsulot</th><th class="text-end">Miqdor</th><th class="text-end">Narx</th><th class="text-end">Jami</th><th></th></tr></thead><tbody>
  <tr class="template" style="display:none"><td><select name="product_id[]" class="form-select form-select-sm"><option value="">—</option><?php foreach($prod as $p): ?><option value="<?=$p['id']?>"><?=$p['code']?> — <?=$p['name']?></option><?php endforeach; ?></select></td>
  <td><input name="qty[]" type="number" class="form-control form-control-sm text-end" step="0.001" value="1"></td><td><input name="price[]" type="number" class="form-control form-control-sm text-end" step="0.01" value="0"></td><td class="text-end line-total">0.00</td>
  <td><button type="button" class="btn btn-outline-secondary btn-sm" onclick="this.closest('tr').remove()"><i class="bi bi-trash"></i></button></td></tr>
  </tbody></table>
  <button type="button" class="btn btn-outline-primary btn-sm" onclick="ItemsTable.addRow('#oItems')"><i class="bi bi-plus"></i> Qator qo‘shish</button>
</div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>

==> ultra-erp-clean-v2.2.zip: src/Views/sales/orders/index.php <==
<h5>Sotuv — Buyurtmalar</h5>
<button class="btn btn-primary btn-sm mb-2" data-bs-toggle="modal" data-bs-target="#oNew"><i class="bi bi-bag-check"></i> Yangi buyurtma</button>
<table class="table table-sm table-hover">
<thead><tr><th>Kod</th><th>Sana</th><th>Mijoz</th><th class="text-end">Jami</th><th>Holat</th><th></th></tr></thead>
<tbody><?php foreach($rows as $r): ?><tr><td><?=$r['code']?></td><td><?=$r['date']?></td><td><?=$r['customer_id']?></td><td class="text-end"><?=$r['total']?></td><td><?=$r['status']?></td>
<td class="text-end"><form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>" onsubmit="return confirm('O‘chirish?')" class="d-inline"><input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button></form></td></tr><?php endforeach; ?></tbody>
</table>

<div class="modal fade" id="oNew" tabindex="-1"><div class="modal-dialog modal-xl"><div class="modal-content">
<div class="modal-header py-2"><h6 class="modal-title">Yangi buyurtma</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>"><div class="modal-body">
  <div class="row row-cols-1 row-cols-md-3 g-2">
    <div class="col"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
    <div class="col"><label class="form-label">Sana</label><input type="date" class="form-control form-control-sm" name="date" required></div>
    <div class="col"><label class="form-label">Mijoz ID</label><input class="form-control form-control-sm" name="customer_id"></div>
  </div><hr class="my-2">
  <table class="table table-sm" id="oItems"><thead><tr><th>Mahsulot</th><th class="text-end">Miqdor</th><th class="text-end">Narx</th><th class="text-end">Jami</th><th></th></tr></thead><tbody>
  <tr class="template" style="display:none"><td><select name="product_id[]" class="form-select form-select-sm"><option value="">—</option><?php foreach($prod as $p): ?><option value="<?=$p['id']?>"><?=$p['code']?> — <?=$p['name']?></option><?php endforeach; ?></select></td>
  <td><input name="qty[]" type="number" class="form-control form-control-sm text-end" step="0.001" value="1"></td><td><input name="price[]" type="number" class="form-control form-control-sm text-end" step="0.01" value="0"></td><td class="text-end line-total">0.00</td>
  <td><button type="button" class="btn btn-outline-secondary btn-sm" onclick="this.closest('tr').remove()"><i class="bi bi-trash"></i></button></td></tr>
  </tbody></table>
  <button type="button" class="btn btn-outline-primary btn-sm" onclick="ItemsTable.addRow('#oItems')"><i class="bi bi-plus"></i> Qator qo‘shish</button>
</div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>
